==> gazie7.30.zip: gazie/modules/vendit/download_zip_package.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
require("../../library/include/datlib.inc.php");
$admin_aziend=checkAdmin();
$d=filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
$file_url = "../../data/files/".$admin_aziend['codice']."/".substr($d['fn'],0,37);
$mime=mime_content_type($file_url);
header('Content-Type: '.$mime);
header("Content-Disposition:attachment;filename='".substr($d['fn'],0,37)."'");
header("Content-Transfer-Encoding: Binary");
header("Content-disposition: attachment; filename=".substr($d['fn'],0,37));
readfile($file_url);

==> gazie8.00.zip: gazie/modules/vendit/download_zip_package.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
require("../../library/include/datlib.inc.php");
$admin_aziend=checkAdmin();
$d=filter_input_array(INPUT_GET, FILTER_SANITIZE_STRING);
$file_url = DATA_DIR."files/".$admin_aziend['codice']."/".substr($d['fn'],0,37);
$mime=mime_content_type($file_url);
header('Content-Type: '.$mime);
header("Content-Disposition:attachment;filename='".substr($d['fn'],0,37)."'");
header("Content-Transfer-Encoding: Binary");
header("Content-disposition: attachment; filename=".substr($d['fn'],0,37));
readfile($file_url);
